using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

namespace OnlinePhotoShop
{
	/// <summary>
	/// Product browser.
	/// </summary>
	/// <requirement>F:products_browse</requirement>
	public class Browse : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.HyperLink HyperLink1;
		protected System.Web.UI.WebControls.Image ProductImage;
		protected System.Web.UI.WebControls.Label ProductHeading;
		protected System.Web.UI.WebControls.Label ProductSummary;
		protected System.Web.UI.HtmlControls.HtmlInputFile Image;
		protected System.Web.UI.WebControls.DropDownList Quantity;
		protected System.Web.UI.WebControls.Button AddButton;
		protected System.Web.UI.WebControls.Label Feedback;
		protected System.Web.UI.WebControls.RadioButtonList Option;
		protected System.Web.UI.WebControls.Button Previous;
		protected System.Web.UI.WebControls.Button Next;
		protected System.Web.UI.WebControls.DropDownList Product;
	
		private void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
			if (!Page.IsPostBack)
			{
				// Initialize the product parser
				ProductParser catalog = new
					ProductParser(Server.MapPath("products.xml"));

				// Get the product list and set it in the Product control
				SortedList products = catalog.ProductList();
				Product.DataValueField = "Key";
				Product.DataTextField = "Value";
				Product.DataSource = products;
				Product.DataBind();
				Product.SelectedIndex = 0;

				// Fill Quantity with a list of numbers
				ArrayList numbers = new ArrayList();
				for (int i = 1; i <= 20; i++)
				{
					numbers.Add(i.ToString());
				}
				Quantity.DataSource = numbers;
				Quantity.DataBind();
				Quantity.SelectedIndex = 0;

				// Update all other controls
				this.UpdateProduct();
			}
		}

		/// <summary>
		/// Updates the ProductHeading, ProductSummary, ProductImage and
		/// Option controls depending on the currently selected product
		/// in the Product control.
		/// </summary>
		private void UpdateProduct()
		{
			ProductParser catalog = new
				ProductParser(Server.MapPath("products.xml"));

			// set the available options for this product
			Option.DataValueField = "Key";
			Option.DataTextField = "Value";
			Option.DataSource = catalog.OptionList(Product.SelectedValue);
			Option.DataBind();
			Option.SelectedIndex = 0;

			// get the product details
			System.Collections.Hashtable details = 
				catalog.ProductDetails(Product.SelectedValue);

			// update controls in product section
			if (details["name"] != null)
				ProductHeading.Text = (string) details["name"];

			if (details["summary"] != null)
				ProductSummary.Text = (string) details["summary"];

			if (details["image"] != null)
				ProductImage.ImageUrl = (string) details["image"];
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Previous.Click += new System.EventHandler(this.Previous_Click);
			this.Product.SelectedIndexChanged += new System.EventHandler(this.Product_SelectedIndexChanged);
			this.Next.Click += new System.EventHandler(this.Next_Click);
			this.AddButton.Click += new System.EventHandler(this.AddButton_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		/// <summary>
		/// Called when a new product is selected in the Product control. Updates the product description and optionlist by calling UpdateProduct().
		/// </summary>
		/// <param name="sender">Sending object.</param>
		/// <param name="e">Event arguments.</param>
		private void Product_SelectedIndexChanged(object sender, System.EventArgs e)
		{
			this.UpdateProduct();
		}

		/// <summary>
		/// Called when a the Next button is pressed. Selects the next product in the list and updates the product description and optionlist by calling UpdateProduct().
		/// </summary>
		/// <param name="sender">Sending object.</param>
		/// <param name="e">Event arguments.</param>
		private void Next_Click(object sender, System.EventArgs e)
		{
			if ((Product.SelectedIndex + 1) < Product.Items.Count)
			{
				Product.SelectedIndex++;
			}
			else
			{
				Product.SelectedIndex = 0;
			}
			this.UpdateProduct();
		}

		/// <summary>
		/// Called when a the Previous button is pressed. Selects the previous product in the list and updates the product description and optionlist by calling UpdateProduct().
		/// </summary>
		/// <param name="sender">Sending object.</param>
		/// <param name="e">Event arguments.</param>
		private void Previous_Click(object sender, System.EventArgs e)
		{
			if (Product.SelectedIndex > 0)
			{
				Product.SelectedIndex--;
			}
			else
			{
				Product.SelectedIndex = Product.Items.Count - 1;
			}
			this.UpdateProduct();
		}

		/// <summary>
		/// Called when Add button is pressed. Adds a new item of the currently selected product, option and quantity to the shopping cart.
		/// </summary>
		/// <param name="sender">Sending object.</param>
		/// <param name="e">Event arguments.</param>
		private void AddButton_Click(object sender, System.EventArgs e)
		{
			// Report error if no image is selected
			if (Image.PostedFile.ContentLength == 0)
			{
				Feedback.Text = "Before adding an item to the shopping cart you must select an image.";
				Feedback.ForeColor = System.Drawing.Color.Red;
			}
			else
			{
				try
				{
					// retrieve shopping cart information from session object
					ShoppingCart cart = 
						(ShoppingCart) Session["ShoppingCart"];
					if (cart == null)
					{
						// no cart in this session yet, create one
						cart = new ShoppingCart(Session.SessionID);
						Session["ShoppingCart"] = cart;
					}
      
					// add the order
					cart.AddItem(
						Product.SelectedValue,
						Option.SelectedValue,
						Image.PostedFile,
						Quantity.SelectedIndex + 1);

					Feedback.Text = Quantity.SelectedValue + " item(s) added to your shopping cart.";
					Feedback.ForeColor = System.Drawing.Color.Black;
				} 
				catch
				{
					Feedback.Text = "The item could not be added to the shopping cart. Please try again another time.";
					Feedback.ForeColor = System.Drawing.Color.Red;
				}
			}
		}

	}
}
